@@ -168,7 +168,7 @@ class JsonWebSignature(object):
         obj = ensure_dict(obj, 'JWS')
 
         payload_segment = obj.get('payload')
-        if not payload_segment:
+        if payload_segment is None:
             raise DecodeError('Missing "payload" value')
 
         payload_segment = to_bytes(payload_segment)
@@ -244,7 +244,7 @@ class JsonWebSignature(object):
             raise MissingAlgorithmError()
 
         alg = header['alg']
-        if self._algorithms and alg not in self._algorithms:
+        if self._algorithms is not None and alg not in self._algorithms:
             raise UnsupportedAlgorithmError()
         if alg not in self.ALGORITHMS_REGISTRY:
             raise UnsupportedAlgorithmError()
@@ -252,7 +252,7 @@ class JsonWebSignature(object):
         algorithm = self.ALGORITHMS_REGISTRY[alg]
         if callable(key):
             key = key(header, payload)
-        elif 'jwk' in header:
+        elif key is None and 'jwk' in header:
             key = header['jwk']
         key = algorithm.prepare_key(key)
         return algorithm, key
