@@ -53,15 +53,18 @@ class BaseClaims(dict):
 
     def _validate_essential_claims(self):
         for k in self.options:
-            if self.options[k].get('essential') and k not in self:
-                raise MissingClaimError(k)
+            if self.options[k].get('essential'):
+                if k not in self:
+                    raise MissingClaimError(k)
+                elif not self.get(k):
+                    raise InvalidClaimError(k)
 
     def _validate_claim_value(self, claim_name):
         option = self.options.get(claim_name)
-        value = self.get(claim_name)
-        if not option or not value:
+        if not option:
             return
 
+        value = self.get(claim_name)
         option_value = option.get('value')
         if option_value and value != option_value:
             raise InvalidClaimError(claim_name)
@@ -100,6 +103,11 @@ class JWTClaims(BaseClaims):
         self.validate_iat(now, leeway)
         self.validate_jti()
 
+        # Validate custom claims
+        for key in self.options.keys():
+            if key not in self.REGISTERED_CLAIMS:
+                self._validate_claim_value(key)
+
     def validate_iss(self):
         """The "iss" (issuer) claim identifies the principal that issued the
         JWT.  The processing of this claim is generally application specific.
