@@ -25,7 +25,7 @@ class JsonWebToken(object):
         r'^\b(?!(000|666|9))\d{3}-(?!00)\d{2}-(?!0000)\d{4}\b',
     ]), re.DOTALL)
 
-    def __init__(self, algorithms=None, private_headers=None):
+    def __init__(self, algorithms, private_headers=None):
         self._jws = JsonWebSignature(algorithms, private_headers=private_headers)
         self._jwe = JsonWebEncryption(algorithms, private_headers=private_headers)
 
@@ -70,7 +70,7 @@ class JsonWebToken(object):
 
     def decode(self, s, key, claims_cls=None,
                claims_options=None, claims_params=None):
-        """Decode the JWS with the given key. This is similar with
+        """Decode the JWT with the given key. This is similar with
         :meth:`verify`, except that it will raise BadSignatureError when
         signature doesn't match.
 
