@@ -1,17 +1,6 @@
 import binascii
-from authlib.common.encoding import urlsafe_b64decode, json_loads
-
-
-def prepare_algorithm_key(algorithms, header, payload, key, private=False):
-    algorithm = algorithms[header['alg']]
-    if callable(key):
-        key = key(header, payload)
-
-    if private:
-        key = algorithm.prepare_private_key(key)
-    else:
-        key = algorithm.prepare_public_key(key)
-    return algorithm, key
+from authlib.common.encoding import urlsafe_b64decode, json_loads, to_unicode
+from authlib.jose.errors import DecodeError
 
 
 def extract_header(header_segment, error_cls):
@@ -33,3 +22,16 @@ def extract_segment(segment, error_cls, name='payload'):
     except (TypeError, binascii.Error):
         msg = 'Invalid {} padding'.format(name)
         raise error_cls(msg)
+
+
+def ensure_dict(s, structure_name):
+    if not isinstance(s, dict):
+        try:
+            s = json_loads(to_unicode(s))
+        except (ValueError, TypeError):
+            raise DecodeError('Invalid {}'.format(structure_name))
+
+    if not isinstance(s, dict):
+        raise DecodeError('Invalid {}'.format(structure_name))
+
+    return s
