@@ -9,6 +9,7 @@ from .rfc6749.parameters import (
 from .rfc7009 import prepare_revoke_token_request
 from .rfc7636 import create_s256_code_challenge
 from .auth import TokenAuth, ClientAuth
+from .base import OAuth2Error
 
 DEFAULT_HEADERS = {
     'Accept': 'application/json',
@@ -28,6 +29,7 @@ class OAuth2Client(object):
     :param revocation_endpoint_auth_method: client authentication method for
         revocation endpoint.
     :param scope: Scope that you needed to access user resources.
+    :param state: Shared secret to prevent CSRF attack.
     :param redirect_uri: Redirect URI you registered as callback.
     :param code_challenge_method: PKCE method name, only S256 is supported.
     :param token: A dict of token attributes such as ``access_token``,
@@ -39,6 +41,7 @@ class OAuth2Client(object):
     """
     client_auth_class = ClientAuth
     token_auth_class = TokenAuth
+    oauth_error_class = OAuth2Error
 
     EXTRA_AUTHORIZE_PARAMS = (
         'response_mode', 'nonce', 'prompt', 'login_hint'
@@ -48,12 +51,13 @@ class OAuth2Client(object):
     def __init__(self, session, client_id=None, client_secret=None,
                  token_endpoint_auth_method=None,
                  revocation_endpoint_auth_method=None,
-                 scope=None, redirect_uri=None, code_challenge_method=None,
+                 scope=None, state=None, redirect_uri=None, code_challenge_method=None,
                  token=None, token_placement='header', update_token=None, **metadata):
 
         self.session = session
         self.client_id = client_id
         self.client_secret = client_secret
+        self.state = state
 
         if token_endpoint_auth_method is None:
             if client_secret:
@@ -170,6 +174,7 @@ class OAuth2Client(object):
         :param grant_type: Use specified grant_type to fetch token
         :return: A :class:`OAuth2Token` object (a dict too).
         """
+        state = state or self.state
         # implicit  grant_type
         authorization_response = kwargs.pop('authorization_response', None)
         if authorization_response and '#' in authorization_response:
@@ -206,7 +211,13 @@ class OAuth2Client(object):
 
     def token_from_fragment(self, authorization_response, state=None):
         token = parse_implicit_response(authorization_response, state)
-        return self.parse_response_token(token)
+        if 'error' in token:
+            raise self.oauth_error_class(
+                error=token['error'],
+                description=token.get('error_description')
+            )
+        self.token = token
+        return token
 
     def refresh_token(self, url, refresh_token=None, body='',
                       auth=None, headers=None, **kwargs):
@@ -230,7 +241,7 @@ class OAuth2Client(object):
         )
 
         if headers is None:
-            headers = DEFAULT_HEADERS
+            headers = DEFAULT_HEADERS.copy()
 
         for hook in self.compliance_hook['refresh_token_request']:
             url, headers, body = hook(url, headers, body)
@@ -320,18 +331,18 @@ class OAuth2Client(object):
                              hook_type, self.compliance_hook)
         self.compliance_hook[hook_type].add(hook)
 
-    def parse_response_token(self, token):
-        if 'error' not in token:
-            self.token = token
-            return self.token
+    def parse_response_token(self, resp):
+        if resp.status_code >= 500:
+            resp.raise_for_status()
 
-        error = token['error']
-        description = token.get('error_description', error)
-        self.handle_error(error, description)
-
-    @staticmethod
-    def handle_error(error_type, error_description):
-        raise ValueError('{}: {}'.format(error_type, error_description))
+        token = resp.json()
+        if 'error' in token:
+            raise self.oauth_error_class(
+                error=token['error'],
+                description=token.get('error_description')
+            )
+        self.token = token
+        return self.token
 
     def _fetch_token(self, url, body='', headers=None, auth=None,
                      method='POST', **kwargs):
@@ -350,8 +361,7 @@ class OAuth2Client(object):
         for hook in self.compliance_hook['access_token_response']:
             resp = hook(resp)
 
-        resp.raise_for_status()
-        return self.parse_response_token(resp.json())
+        return self.parse_response_token(resp)
 
     def _refresh_token(self, url, refresh_token=None, body='', headers=None,
                        auth=None, **kwargs):
@@ -360,8 +370,7 @@ class OAuth2Client(object):
         for hook in self.compliance_hook['refresh_token_response']:
             resp = hook(resp)
 
-        resp.raise_for_status()
-        token = self.parse_response_token(resp.json())
+        token = self.parse_response_token(resp)
         if 'refresh_token' not in token:
             self.token['refresh_token'] = refresh_token
 
