@@ -1,4 +1,5 @@
 from .authenticate_client import ClientAuthentication
+from .requests import OAuth2Request, JsonRequest
 from .errors import (
     OAuth2Error,
     InvalidScopeError,
@@ -60,7 +61,7 @@ class AuthorizationServer(object):
     def register_token_generator(self, grant_type, func):
         """Register a function as token generator for the given ``grant_type``.
         Developers MUST register a default token generator with a special
-        ``grant_type=none``::
+        ``grant_type=default``::
 
             def generate_bearer_token(grant_type, client, user=None, scope=None,
                                       expires_in=None, include_refresh_token=True):
@@ -70,7 +71,7 @@ class AuthorizationServer(object):
                 ...
                 return token
 
-            authorization_server.register_token_generator('none', generate_bearer_token)
+            authorization_server.register_token_generator('default', generate_bearer_token)
 
         If you register a generator for a certain grant type, that generator will only works
         for the given grant type::
@@ -127,7 +128,7 @@ class AuthorizationServer(object):
         """
         raise NotImplementedError()
 
-    def create_oauth2_request(self, request):
+    def create_oauth2_request(self, request) -> OAuth2Request:
         """This method MUST be implemented in framework integrations. It is
         used to create an OAuth2Request instance.
 
@@ -136,7 +137,7 @@ class AuthorizationServer(object):
         """
         raise NotImplementedError()
 
-    def create_json_request(self, request):
+    def create_json_request(self, request) -> JsonRequest:
         """This method MUST be implemented in framework integrations. It is
         used to create an HttpRequest instance.
 
