@@ -6,6 +6,7 @@ from ..errors import (
     OAuth2Error,
     UnauthorizedClientError,
     InvalidClientError,
+    InvalidGrantError,
     InvalidRequestError,
     AccessDeniedError,
 )
@@ -106,7 +107,7 @@ class AuthorizationCodeGrant(BaseGrant, AuthorizationEndpointMixin, TokenEndpoin
         """
         return validate_code_authorization_request(self)
 
-    def create_authorization_response(self, redirect_uri, grant_user):
+    def create_authorization_response(self, redirect_uri: str, grant_user):
         """If the resource owner grants the access request, the authorization
         server issues an authorization code and delivers it to the client by
         adding the following parameters to the query component of the
@@ -220,18 +221,18 @@ class AuthorizationCodeGrant(BaseGrant, AuthorizationEndpointMixin, TokenEndpoin
         # code was issued to "client_id" in the request
         authorization_code = self.query_authorization_code(code, client)
         if not authorization_code:
-            raise InvalidRequestError('Invalid "code" in request.')
+            raise InvalidGrantError('Invalid "code" in request.')
 
         # validate redirect_uri parameter
         log.debug('Validate token redirect_uri of %r', client)
         redirect_uri = self.request.redirect_uri
         original_redirect_uri = authorization_code.get_redirect_uri()
         if original_redirect_uri and redirect_uri != original_redirect_uri:
-            raise InvalidRequestError('Invalid "redirect_uri" in request.')
+            raise InvalidGrantError('Invalid "redirect_uri" in request.')
 
         # save for create_token_response
         self.request.client = client
-        self.request.credential = authorization_code
+        self.request.authorization_code = authorization_code
         self.execute_hook('after_validate_token_request')
 
     def create_token_response(self):
@@ -263,11 +264,11 @@ class AuthorizationCodeGrant(BaseGrant, AuthorizationEndpointMixin, TokenEndpoin
         .. _`Section 4.1.4`: https://tools.ietf.org/html/rfc6749#section-4.1.4
         """
         client = self.request.client
-        authorization_code = self.request.credential
+        authorization_code = self.request.authorization_code
 
         user = self.authenticate_user(authorization_code)
         if not user:
-            raise InvalidRequestError('There is no "user" for this code.')
+            raise InvalidGrantError('There is no "user" for this code.')
         self.request.user = user
 
         scope = authorization_code.get_scope()
