@@ -9,15 +9,19 @@
     https://tools.ietf.org/html/rfc6750
 """
 
-from .errors import InvalidRequestError, InvalidTokenError, InsufficientScopeError
+from .errors import InvalidTokenError, InsufficientScopeError
 from .parameters import add_bearer_token
-from .wrappers import BearerToken
+from .token import BearerTokenGenerator
 from .validator import BearerTokenValidator
 
+# TODO: add deprecation
+BearerToken = BearerTokenGenerator
+
 
 __all__ = [
-    'InvalidRequestError', 'InvalidTokenError', 'InsufficientScopeError',
+    'InvalidTokenError', 'InsufficientScopeError',
     'add_bearer_token',
     'BearerToken',
+    'BearerTokenGenerator',
     'BearerTokenValidator',
 ]
