@@ -9,7 +9,7 @@
     https://tools.ietf.org/html/rfc7009
 """
 
-# flake8: noqa
-
 from .parameters import prepare_revoke_token_request
 from .revocation import RevocationEndpoint
+
+__all__ = ['prepare_revoke_token_request', 'RevocationEndpoint']
